Learn R Programming

rbiorxiv (version 0.2.1)

biorxiv_content: Retrieve details of bioRxiv or medRxiv preprints

Description

Retrieve details of bioRxiv or medRxiv preprints

Usage

biorxiv_content(
  server = "biorxiv",
  from = NULL,
  to = NULL,
  doi = NULL,
  limit = 100,
  skip = 0,
  format = "list"
)

Arguments

server

(character) The preprint server to be queried; value must be one of "biorxiv" or "medrxiv". Default: biorxiv

from

(date) The date from when details of preprints should be collected. Date must be supplied in YYYY-MM-DD format. Default: NULL

to

(date) The date until when details of preprints should be collected. Date must be supplied in YYYY-MM-DD format. Default: NULL

doi

(character) A single digital object identifier (DOI) of a preprint. doi cannot be used with from and to arguments. Default: NULL

limit

(integer) The maximum number of results to return. Not relevant when querying a doi. Default: 100

skip

(integer) The number of results to skip in a query. Default: 0

format

(character) Return data in list list, json json or data frame df format. Default: list

Beware

Querying for a DOI will only work for DOIs associated with bioRxiv or medRxiv

Examples

Run this code
# NOT RUN {
# Get details of preprints deposited between 2018-01-01 and 2018-01-10
# By default, only the first 100 records are returned
biorxiv_content(from = "2018-01-01", to = "2018-01-10")

# Set a limit to return more than 100 records
biorxiv_content(from = "2018-01-01", to = "2018-01-10", limit = 200)

# Set limit as "*" to return all records
biorxiv_content(from = "2018-01-01", to = "2018-01-10", limit = "*")

# Skip the first 100 records
biorxiv_content(from = "2018-01-01", to = "2018-01-10",
                limit = 200, skip = 100)

# Specify the format to return data
biorxiv_content(from = "2018-01-01", to = "2018-01-10", format = "df")

# Lookup a preprint by DOI
biorxiv_content(doi = "10.1101/833400")
# }

Run the code above in your browser using DataLab