Learn R Programming

rbiorxiv (version 0.2.1)

biorxiv_published: Retrieve details of published articles with bioRxiv preprints

Description

Retrieve details of published articles with bioRxiv preprints

Usage

biorxiv_published(
  from = NULL,
  to = NULL,
  limit = 100,
  skip = 0,
  format = "list"
)

Arguments

from

(date) The date from when details of published articles should be collected. Date must be supplied in YYYY-MM-DD format. Default: NULL

to

(date) The date until when details of published articles should be collected. Date must be supplied in YYYY-MM-DD format. Default: NULL

limit

(integer) The maximum number of results to return. Not relevant when querying a doi. Default: 100

skip

(integer) The number of results to skip in a query. Default: 0

format

(character) Return data in list list, json json or data frame df format. Default: list

Examples

Run this code
# NOT RUN {
# Get details of articles published between 2018-01-01 and 2018-01-10
# By default, only the first 100 records are returned
biorxiv_published(from = "2018-01-01", to = "2018-01-10")

# Set a limit to return more than 100 records
biorxiv_published(from = "2018-01-01", to = "2018-01-10", limit = 200)

# Set limit as "*" to return all records
biorxiv_published(from = "2018-01-01", to = "2018-01-10", limit = "*")

# Skip the first 100 records
biorxiv_published(from = "2018-01-01", to = "2018-01-10",
                  limit = 200, skip = 100)

# Specify the format to return data
biorxiv_published(from = "2018-01-01", to = "2018-01-10", format = "df")
# }

Run the code above in your browser using DataLab