Learn R Programming

rbiorxiv (version 0.2.1)

biorxiv_publisher: Retrieve details of published articles with bioRxiv preprints by a specific publisher

Description

Retrieve details of published articles with bioRxiv preprints by a specific publisher

Usage

biorxiv_publisher(
  prefix = NULL,
  from = NULL,
  to = NULL,
  limit = 100,
  skip = 0,
  format = "list"
)

Arguments

prefix

(character) The prefix of a digital object identifier (DOI) associated with a publisher. Default: NULL

from

(date) The date from when details of published articles should be collected. Date must be supplied in YYYY-MM-DD format. Default: NULL

to

(date) The date until when details of published articles should be collected. Date must be supplied in YYYY-MM-DD format. Default: NULL

limit

(integer) The maximum number of results to return. Not relevant when querying a doi. Default: 100

skip

(integer) The number of results to skip in a query. Default: 0

format

(character) Return data in list list, json json or data frame df format. Default: list

Examples

Run this code
# NOT RUN {
# Get details of articles published by eLife (doi prefix = 10.7554)
# between 2018-01-01 and 2018-01-30
# By default, only the first 100 records are returned
biorxiv_publisher(prefix = "10.7554", from = "2017-01-01", to = "2018-01-01")

# Set a limit to return more than 100 records
biorxiv_publisher(prefix = "10.7554", from = "2017-01-01", to = "2018-01-01",
                  limit = 200)

# Set limit as "*" to return all records
biorxiv_publisher(prefix = "10.7554", from = "2017-01-01", to = "2018-01-01",
                  limit = "*")

# Skip the first 100 records
biorxiv_publisher(prefix = "10.7554", from = "2017-01-01", to = "2018-01-01",
                  limit = 200, skip = 100)

# Specify the format to return data
biorxiv_publisher(prefix = "10.7554", from = "2017-01-01", to = "2018-01-01",
                  format = "df")
# }

Run the code above in your browser using DataLab